;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                       ;;
;;;                Centre for Speech Technology Research                  ;;
;;;                     University of Edinburgh, UK                       ;;
;;;                       Copyright (c) 1996,1997                         ;;
;;;                        All Rights Reserved.                           ;;
;;;                                                                       ;;
;;;  Permission to use, copy, modify, distribute this software and its    ;;
;;;  documentation for research, educational and individual use only, is  ;;
;;;  hereby granted without fee, subject to the following conditions:     ;;
;;;   1. The code must retain the above copyright notice, this list of    ;;
;;;      conditions and the following disclaimer.                         ;;
;;;   2. Any modifications must be clearly marked as such.                ;;
;;;   3. Original authors' names are not deleted.                         ;;
;;;  This software may not be used for commercial purposes without        ;;
;;;  specific prior written permission from the authors.                  ;;
;;;                                                                       ;;
;;;  THE UNIVERSITY OF EDINBURGH AND THE CONTRIBUTORS TO THIS WORK        ;;
;;;  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      ;;
;;;  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   ;;
;;;  SHALL THE UNIVERSITY OF EDINBURGH NOR THE CONTRIBUTORS BE LIABLE     ;;
;;;  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    ;;
;;;  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   ;;
;;;  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          ;;
;;;  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       ;;
;;;  THIS SOFTWARE.                                                       ;;
;;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;   A hand specified tree to predict zcore durations
;;;
;;;

(set! net_dutch_frans::zdur_tree 
 '
   ((R:SylStructure.parent.R:Syllable.p.syl_break > 1 ) ;; clause initial
    ((1.5))
    ((R:SylStructure.parent.syl_break > 1)   ;; clause final
     ((1.5))                                 ;; longer dur for end of clause
     ((1.0)))))

(set! net_dutch_frans::phone_durs
'(
   ;;; PHONE DATA  
   ;; name zero mean in seconds e.g.
   (# 0.0 0.12)
   ; all other phones on net_dutch phoneset

   (ux 0.0 0.070) ;; nUl
   (e: 0.0 0.070) ;; EEn
   (a  0.0 0.060) ;; Acht
   (i: 0.0 0.100) ;; drIE
   (Ei 0.0 0.175) ;; vIJf
   (e  0.0 0.100) ;; zEs
   (&  0.0 0.030) ;; negEn

   (n  0.0 0.050) ;; Nul
   (V[ 0.0 0.060) ;; tWee
   (t  0.0 0.060) ;; Twee
   (d  0.0 0.025) ;; Drie
   (R  0.0 0.040) ;; dRie
   (l  0.0 0.070) ;; nuL
   (s  0.0 0.060) ;; zeS
   (x  0.0 0.100) ;; aCHt
   (G  0.0 0.060) ;; neGen
   (f  0.0 0.100) ;; vijF
   (v  0.0 0.090) ;; Vijf
   (z  0.0 0.060) ;; Zes
 
))

(provide 'net_dutch_frans_durdata)
